@@ -21,6 +21,7 @@ from manila_tempest_tests.common import constants
 from manila_tempest_tests.common import remote_client
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests.tests.scenario import manager
+from manila_tempest_tests import utils
 
 from tempest.common import waiters
 from tempest import config
@@ -46,8 +47,8 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         return self.ip_version == 6
 
     @classmethod
-    def resource_setup(cls):
-        super(ShareScenarioTest, cls).resource_setup()
+    def setup_clients(cls):
+        super(ShareScenarioTest, cls).setup_clients()
 
         # Manila clients
         cls.shares_client = cls.os_primary.share_v1.SharesClient()
@@ -199,9 +200,10 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         :param output_file: Path to the file to be written
         :param input_file: Path to the file to read from
         """
-
+        block_count = int(block_count)
         remote_client.exec_command(
-            "sudo sh -c \"dd bs={} count={} if={} of={} conv=fsync\""
+            "sudo sh -c \"dd bs={} count={} if={} of={} conv=fsync"
+            " iflag=fullblock\""
             .format(block_size, block_count, input_file, output_file))
 
     def read_data_from_mounted_share(self,
@@ -309,11 +311,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
                                              client=None):
         share = share or self.share
         client = client or self.shares_v2_client
-        if self.protocol.lower() == 'cifs':
-            self.allow_access_ip(
-                share['id'], instance=instance, cleanup=False,
-                snapshot=snapshot, access_level=access_level, client=client)
-        elif not CONF.share.multitenancy_enabled:
+        if not CONF.share.multitenancy_enabled:
             if self.ipv6_enabled:
                 server_ip = self._get_ipv6_server_ip(instance)
             else:
@@ -324,8 +322,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
                 share['id'], ip=server_ip,
                 instance=instance, cleanup=False, snapshot=snapshot,
                 access_level=access_level, client=client)
-        elif (CONF.share.multitenancy_enabled and
-              self.protocol.lower() == 'nfs'):
+        else:
             return self.allow_access_ip(
                 share['id'], instance=instance, cleanup=False,
                 snapshot=snapshot, access_level=access_level, client=client)
@@ -347,6 +344,15 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
                 'driver_handles_share_servers': CONF.share.multitenancy_enabled
             },)['share_type']
 
+    def get_share_export_locations(self, share):
+        if utils.is_microversion_lt(CONF.share.max_api_microversion, "2.9"):
+            locations = share['export_locations']
+        else:
+            exports = self.shares_v2_client.list_share_export_locations(
+                share['id'])
+            locations = [x['path'] for x in exports]
+        return locations
+
     def _get_ipv6_server_ip(self, instance):
         for net_list in instance['addresses'].values():
             for net_data in net_list:
